@@ -1,3 +1,7 @@
+( cd opt/kde/lib/kde3 ; rm -rf libdialogpages.so )
+( cd opt/kde/lib/kde3 ; ln -sf libdialogpages.so.0.0.0 libdialogpages.so )
+( cd opt/kde/lib/kde3 ; rm -rf libdialogpages.so.0 )
+( cd opt/kde/lib/kde3 ; ln -sf libdialogpages.so.0.0.0 libdialogpages.so.0 )
 ( cd opt/kde/lib ; rm -rf libkbabelcommon.so )
 ( cd opt/kde/lib ; ln -sf libkbabelcommon.so.3.2.0 libkbabelcommon.so )
 ( cd opt/kde/lib ; rm -rf libkspy.so.1 )
